%global _hardened_build 1

Name:             bird
Version:          1.6.7
Release:          1%{?dist}
Summary:          BIRD Internet Routing Daemon

Group:            System Environment/Daemons
License:          GPLv2+
URL:              https://bird.network.cz
Source0:          ftp://bird.network.cz/pub/bird/bird-%{version}.tar.gz
Source1:          bird.service
Source2:          bird.tmpfilesd
Patch0:           bird-1.6.6-runstatedir.patch

BuildRequires:    flex bison ncurses-devel readline-devel sed systemd gcc
%{?systemd_requires}
Obsoletes:        bird-sysvinit

%description
BIRD is a dynamic IP routing daemon supporting both, IPv4 and IPv6, Border
Gateway Protocol (BGPv4), Routing Information Protocol (RIPv2, RIPng), Open
Shortest Path First protocol (OSPFv2, OSPFv3), Babel Routing Protocol (Babel),
Bidirectional Forwarding Detection (BFD), IPv6 router advertisements, static
routes, inter-table protocol, command-line interface allowing on-line control
and inspection of the status of the daemon, soft reconfiguration as well as a
powerful language for route filtering.

This package contains IPv4 version.


%package -n bird6
Summary:          BIRD Internet Routing Daemon
Group:            System Environment/Daemons
%{?systemd_requires}
Obsoletes:        bird6-sysvinit

%description -n bird6
BIRD is a dynamic IP routing daemon supporting both, IPv4 and IPv6, Border
Gateway Protocol (BGPv4), Routing Information Protocol (RIPv2, RIPng), Open
Shortest Path First protocol (OSPFv2, OSPFv3), Babel Routing Protocol (Babel),
Bidirectional Forwarding Detection (BFD), IPv6 router advertisements, static
routes, inter-table protocol, command-line interface allowing on-line control
and inspection of the status of the daemon, soft reconfiguration as well as a
powerful language for route filtering.

This package contains IPv6 version.


%package doc
Summary:          Documentation for BIRD Internet Routing Daemon
Group:            Documentation
BuildRequires:    linuxdoc-tools sgml-common
BuildArch:        noarch

%description doc
Documentation for users and programmers of the BIRD Internet Routing Daemon.

BIRD is a dynamic IP routing daemon supporting both, IPv4 and IPv6, Border
Gateway Protocol (BGPv4), Routing Information Protocol (RIPv2, RIPng), Open
Shortest Path First protocol (OSPFv2, OSPFv3), Babel Routing Protocol (Babel),
Bidirectional Forwarding Detection (BFD), IPv6 router advertisements, static
routes, inter-table protocol, command-line interface allowing on-line control
and inspection of the status of the daemon, soft reconfiguration as well as a
powerful language for route filtering.


%prep
%setup -q
%patch0 -p1 -b .runstatedir


%build
mkdir ipv6
tar c --exclude ipv6 . | tar x -C ipv6

cd ipv6
%configure --runstatedir=%{_rundir}/bird6 --enable-ipv6
%make_build all
cd ..

%configure --runstatedir=%{_rundir}/bird
%make_build all docs


%install
%make_install

cd ipv6
%make_install
cd ..

install -d %{buildroot}{%{_unitdir},%{_tmpfilesdir}}
install -d %{buildroot}{%{_localstatedir}/lib,%{_rundir}}/bird{,6}
sed 's/BIRD_PROGNAME/bird/g' %SOURCE1 > %{buildroot}%{_unitdir}/bird.service
sed 's/BIRD_PROGNAME/bird6/g' %SOURCE1 > %{buildroot}%{_unitdir}/bird6.service
sed 's/BIRD_PROGNAME/bird/g' %SOURCE2 > %{buildroot}%{_tmpfilesdir}/bird.conf
sed 's/BIRD_PROGNAME/bird6/g' %SOURCE2 > %{buildroot}%{_tmpfilesdir}/bird6.conf


%post
%systemd_post bird.service

%pre
getent group bird >/dev/null || groupadd -r bird
getent passwd bird >/dev/null || \
  useradd -r -g bird -d %{_localstatedir}/lib/bird -s /sbin/nologin \
  -c "BIRD daemon user" bird
exit 0

%preun
%systemd_preun bird.service

%postun
%systemd_postun_with_restart bird.service

%pre -n bird6
getent group bird6 >/dev/null || groupadd -r bird6
getent passwd bird6 >/dev/null || \
  useradd -r -g bird6 -d %{_localstatedir}/lib/bird6 -s /sbin/nologin \
  -c "BIRD6 daemon user" bird6
exit 0

%post -n bird6
%systemd_post bird6.service

%preun -n bird6
%systemd_preun bird6.service

%postun -n bird6
%systemd_postun_with_restart bird6.service


%files
%doc NEWS README
%attr(0640,root,bird) %config(noreplace) %{_sysconfdir}/bird.conf
%{_unitdir}/bird.service
%{_tmpfilesdir}/bird.conf
%{_sbindir}/bird
%{_sbindir}/birdc
%{_sbindir}/birdcl
%dir %attr(0750,bird,bird) %{_localstatedir}/lib/bird
%dir %attr(0750,bird,bird) %{_rundir}/bird

%files -n bird6
%doc NEWS README
%attr(0640,root,bird6) %config(noreplace) %{_sysconfdir}/bird6.conf
%{_unitdir}/bird6.service
%{_tmpfilesdir}/bird6.conf
%{_sbindir}/bird6
%{_sbindir}/birdc6
%{_sbindir}/birdcl6
%dir %attr(0750,bird6,bird6) %{_localstatedir}/lib/bird6
%dir %attr(0750,bird6,bird6) %{_rundir}/bird6

%files doc
%doc NEWS README
%doc doc/bird.conf.*
%doc doc/bird*.html
%doc doc/bird.pdf
%doc doc/prog*.html
%doc doc/prog.pdf


%changelog
* Mon Aug 05 2019 Robert Scheck <robert@fedoraproject.org> - 1.6.7-1
- Upgrade to 1.6.7

* Sat Apr 06 2019 Robert Scheck <robert@fedoraproject.org> - 1.6.6-1
- Upgrade to 1.6.6
- Modernization and cleanup of spec file
- Ensure /etc/bird.conf can be only read by BIRD user

* Mon Nov 19 2018 Stanislav Kozina <skozina@redhat.org> - 1.6.4-2
- Fix running bird under non-root user and group

* Mon Nov 19 2018 Stanislav Kozina <skozina@redhat.org> - 1.6.4-1
- Update to 1.6.4
- Fix CVE-2018-12066 (#1588770)

* Mon Jun 29 2015 Michal Sekletar <msekleta@redhat.com> - 1.4.5-2
- fix the bug in locking code (#1235219)

* Wed Dec 03 2014 Michal Sekletar <msekleta@redhat.com> - 1.4.5-1
- update to 1.4.5

* Fri May 23 2014 Michal Sekletar <msekleta@redhat.com> - 1.4.3-1
- update to 1.4.3

* Tue Dec 03 2013 Michal Sekletar <msekleta@redhat.com> - 1.4.0-1
- update to 1.4.0

* Thu Oct 17 2013 Michal Sekletar <msekleta@redhat.com> - 1.3.11-1
- update to 1.3.11
- add systemd to BuildRequires
- change scriptlet Requires to systemd
- drop rpm triggers used for migration from sysv to systemd
- drop sysvinit subpackages
- use macroized systemd scriptlets
- specfile cleanup
- enable hardened build
- modernize systemd service file

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.10-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed Jul 03 2013 Stanislav Kozina <stanislav.kozina@gmail.com> 1.3.10-1
- updated to latest upstream 1.3.10

* Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.7-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Wed Jul 18 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.7-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Wed Apr 04 2012 Stanislav Kozina <skozina@redhat.com> 1.3.7-1
- updated to latest upstream 1.3.7

* Wed Jan 11 2012 Jiri Skala <jskala@redhat.com> 1.3.5-1
- updated to latest upstream 1.3.5

* Wed Nov 23 2011 Jiri Skala <jskala@redhat.com> 1.3.4-2
- initscripts moved to subpackage

* Mon Oct 10 2011 Jiri Skala <jskala@redhat.com> 1.3.4-1
- updated to latest upstream 1.3.4

* Mon Sep 12 2011 Jiri Skala <jskala@redhat.com> 1.3.3-1
- updated to latest upstream 1.3.3

* Mon Jul 11 2011 Jiri Skala <jskala@redhat.com> 1.3.2-1
- updated to latest upstream 1.3.2

* Wed May 11 2011 Bill Nottingham <notting@redhat.com>  1.3.1-2
- fix systemd scriptlets for upgrade (#703234)

* Wed May 04 2011 Jan Görig <jgorig@redhat.com> 1.3.1-1
- New upstream bugfix release

* Thu Mar 31 2011 Jan Görig <jgorig@redhat.com> 1.3.0-1
- New upstream release - iBGP improved, IPv6 RA added, many changes and bufixes
- Updated systemd unit files configuration

* Mon Feb 07 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org>
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Thu Nov 11 2010 Jan Görig <jgorig@redhat.com> 1.2.5-2
- Move from SysVInit to systemd

* Mon Oct 11 2010 Jan Görig <jgorig@redhat.com> 1.2.5-1
- New upstream release

* Tue Oct 5 2010 Jan Görig <jgorig@redhat.com> 1.2.4-1
- Initial release
